@@ -209,6 +209,12 @@ class TTTH_Analyzer:
         return class_count
 
     def check_imbalance_class(self, variable_name, df):
+        """
+        Check ratio of each class
+        :param variable_name: Variable name
+        :param df: DataFrame contains category
+        :return:
+        """
         class_count = self._count_values_of_variable(variable_name, df, normalize=True)
         print(f'Class count of {variable_name}:\n')
         print('==========')
